<?php
/**
 * Store_API_Extension class.
 *
 * A class to extend the store public API with Distance Rate Shipping Abort Message functionality.
 *
 * @package woocommerce-distance-rate-shipping
 */

namespace WooCommerce\DistanceRate;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Automattic\WooCommerce\StoreApi\StoreApi;
use Automattic\WooCommerce\StoreApi\Schemas\ExtendSchema;
use Automattic\WooCommerce\StoreApi\Schemas\V1\CartSchema;

/**
 * Store API Extension.
 */
class Store_API_Extension {
	/**
	 * Stores Rest Extending instance.
	 *
	 * @var ExtendSchema
	 */
	private static $extend;

	/**
	 * Plugin Identifier, unique to each plugin.
	 *
	 * @var string
	 */
	const IDENTIFIER = 'woocommerce_distance_rate_shipping';

	/**
	 * Bootstraps the class and hooks required data.
	 *
	 * @since 1.0.0
	 */
	public static function init() {
		self::$extend = StoreApi::container()->get( ExtendSchema::class );
		self::extend_store();
	}

	/**
	 * Registers the data into each endpoint.
	 */
	public static function extend_store() {

		self::$extend->register_endpoint_data(
			array(
				'endpoint'        => CartSchema::IDENTIFIER,
				'namespace'       => self::IDENTIFIER,
				'data_callback'   => array( static::class, 'data' ),
				'schema_callback' => array( static::class, 'schema' ),
				'schema_type'     => ARRAY_A,
			)
		);
	}

	/**
	 * Store API extension data callback.
	 *
	 * @return array
	 */
	public static function data() {
		$notices = WC()->session->get( Notifier::WC_SESSION_KEY, array() );
		$notices = is_array( $notices ) && isset( $notices['notice'] ) ? $notices['notice'] : array();

		$aborts = array();

		foreach ( $notices as $notice ) {
			if ( empty( $notice['group'] || empty( $notice['message'] ) ) ) {
				continue;
			}

			if ( 'abort' !== $notice['group'] ) {
				continue;
			}

			$aborts[] = $notice['message'];
		}

		return array(
			'abort_messages' => $aborts,
		);
	}

	/**
	 * Store API extension schema callback.
	 *
	 * @return array Registered schema.
	 */
	public static function schema() {
		return array(
			'abort_messages' => array(
				'description' => __( 'Abort messages from Distance Rate Shipping.', 'woocommerce-distance-rate-shipping' ),
				'type'        => 'array',
				'context'     => array( 'view', 'edit' ),
				'readonly'    => true,
			),
		);
	}
}
